@@ -50,8 +50,8 @@ _GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
 
 class ContainerAnalysisClient(object):
     """
-    Retrieves analysis results of Cloud components such as Docker container
-    images. The Container Analysis API is an implementation of the
+    Retrieves analysis results of Cloud components such as Docker
+    container images. The Container Analysis API is an implementation of the
     `Grafeas <https://grafeas.io>`__ API.
 
     Analysis results are stored as a series of occurrences. An
@@ -179,13 +179,17 @@ class ContainerAnalysisClient(object):
                     )
                 self.transport = transport
         else:
-            self.transport = container_analysis_grpc_transport.ContainerAnalysisGrpcTransport(
-                address=api_endpoint, channel=channel, credentials=credentials
+            self.transport = (
+                container_analysis_grpc_transport.ContainerAnalysisGrpcTransport(
+                    address=api_endpoint,
+                    channel=channel,
+                    credentials=credentials,
+                )
             )
 
         if client_info is None:
             client_info = google.api_core.gapic_v1.client_info.ClientInfo(
-                gapic_version=_GAPIC_LIBRARY_VERSION
+                gapic_version=_GAPIC_LIBRARY_VERSION,
             )
         else:
             client_info.gapic_version = _GAPIC_LIBRARY_VERSION
@@ -196,7 +200,7 @@ class ContainerAnalysisClient(object):
         # (Ordinarily, these are the defaults specified in the `*_config.py`
         # file next to this one.)
         self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
-            client_config["interfaces"][self._INTERFACE_NAME]
+            client_config["interfaces"][self._INTERFACE_NAME],
         )
 
         # Save a dictionary of cached API call functions.
@@ -289,7 +293,10 @@ class ContainerAnalysisClient(object):
                 client_info=self._client_info,
             )
 
-        request = iam_policy_pb2.SetIamPolicyRequest(resource=resource, policy=policy)
+        request = iam_policy_pb2.SetIamPolicyRequest(
+            resource=resource,
+            policy=policy,
+        )
         if metadata is None:
             metadata = []
         metadata = list(metadata)
@@ -374,7 +381,8 @@ class ContainerAnalysisClient(object):
             )
 
         request = iam_policy_pb2.GetIamPolicyRequest(
-            resource=resource, options=options_
+            resource=resource,
+            options=options_,
         )
         if metadata is None:
             metadata = []
@@ -426,8 +434,8 @@ class ContainerAnalysisClient(object):
         Args:
             resource (str): REQUIRED: The resource for which the policy detail is being requested.
                 See the operation documentation for the appropriate value for this field.
-            permissions (list[str]): The set of permissions to check for the ``resource``. Permissions with
-                wildcards (such as '*' or 'storage.*') are not allowed. For more
+            permissions (list[str]): The set of permissions to check for the ``resource``. Permissions
+                with wildcards (such as '*' or 'storage.*') are not allowed. For more
                 information see `IAM
                 Overview <https://cloud.google.com/iam/docs/overview#permissions>`__.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
@@ -461,7 +469,8 @@ class ContainerAnalysisClient(object):
             )
 
         request = iam_policy_pb2.TestIamPermissionsRequest(
-            resource=resource, permissions=permissions
+            resource=resource,
+            permissions=permissions,
         )
         if metadata is None:
             metadata = []
